@@ -18,7 +18,7 @@
 
 #ifdef MONGOC_ENABLE_SSL_SECURE_CHANNEL
 
-#include <bson.h>
+#include <bson/bson.h>
 
 #include "mongoc-log.h"
 #include "mongoc-trace-private.h"
@@ -54,9 +54,6 @@ mongoc_secure_channel_setup_certificate_from_file (const char *filename)
    LPBYTE blob_private = NULL;
    PCCERT_CONTEXT cert = NULL;
    DWORD blob_private_len = 0;
-   HCERTSTORE cert_store = NULL;
-   DWORD encrypted_cert_len = 0;
-   LPBYTE encrypted_cert = NULL;
    DWORD encrypted_private_len = 0;
    LPBYTE encrypted_private = NULL;
 
@@ -114,12 +111,12 @@ mongoc_secure_channel_setup_certificate_from_file (const char *filename)
       NULL, /* phCertStore, OUT, HCERTSTORE.., unused, for now */
       NULL, /* phMsg, OUT, HCRYPTMSG, only for PKC7, unused */
       (const void **) &cert /* ppvContext, OUT, the Certificate Context */
-   );
+      );
 
    if (!cert) {
       MONGOC_ERROR ("Failed to extract public key from '%s'. Error 0x%.8X",
                     filename,
-                    GetLastError ());
+                    (unsigned int) GetLastError ());
       goto fail;
    }
 
@@ -135,7 +132,7 @@ mongoc_secure_channel_setup_certificate_from_file (const char *filename)
                             NULL);                     /* pdwFlags */
    if (!success) {
       MONGOC_ERROR ("Failed to convert base64 private key. Error 0x%.8X",
-                    GetLastError ());
+                    (unsigned int) GetLastError ());
       goto fail;
    }
 
@@ -149,7 +146,7 @@ mongoc_secure_channel_setup_certificate_from_file (const char *filename)
                                    NULL);
    if (!success) {
       MONGOC_ERROR ("Failed to convert base64 private key. Error 0x%.8X",
-                    GetLastError ());
+                    (unsigned int) GetLastError ());
       goto fail;
    }
 
@@ -175,8 +172,9 @@ mongoc_secure_channel_setup_certificate_from_file (const char *filename)
                      (LPTSTR) &msg,
                      0,
                      NULL);
-      MONGOC_ERROR (
-         "Failed to parse private key. %s (0x%.8X)", msg, GetLastError ());
+      MONGOC_ERROR ("Failed to parse private key. %s (0x%.8X)",
+                    msg,
+                    (unsigned int) GetLastError ());
       LocalFree (msg);
       goto fail;
    }
@@ -192,7 +190,7 @@ mongoc_secure_channel_setup_certificate_from_file (const char *filename)
                                   &blob_private_len);
    if (!success) {
       MONGOC_ERROR ("Failed to parse private key. Error 0x%.8X",
-                    GetLastError ());
+                    (unsigned int) GetLastError ());
       goto fail;
    }
 
@@ -205,7 +203,7 @@ mongoc_secure_channel_setup_certificate_from_file (const char *filename)
                                   CRYPT_VERIFYCONTEXT); /* dwFlags */
    if (!success) {
       MONGOC_ERROR ("CryptAcquireContext failed with error 0x%.8X",
-                    GetLastError ());
+                    (unsigned int) GetLastError ());
       goto fail;
    }
 
@@ -219,7 +217,7 @@ mongoc_secure_channel_setup_certificate_from_file (const char *filename)
                              &hKey);           /* phKey, OUT */
    if (!success) {
       MONGOC_ERROR ("CryptImportKey for private key failed with error 0x%.8X",
-                    GetLastError ());
+                    (unsigned int) GetLastError ());
       goto fail;
    }
 
@@ -236,7 +234,7 @@ mongoc_secure_channel_setup_certificate_from_file (const char *filename)
    }
 
    MONGOC_ERROR ("Can't associate private key with public key: 0x%.8X",
-                 GetLastError ());
+                 (unsigned int) GetLastError ());
 
 fail:
    SecureZeroMemory (pem, pem_length);
@@ -317,7 +315,7 @@ mongoc_secure_channel_setup_ca (
 
    file = fopen (opt->ca_file, "rb");
    if (!file) {
-      MONGOC_WARNING ("Couldn't open file '%s'", opt->ca_file);
+      MONGOC_ERROR ("Couldn't open file '%s'", opt->ca_file);
       return false;
    }
 
@@ -338,7 +336,7 @@ mongoc_secure_channel_setup_ca (
    /*printf ("%s\n", pem_key);*/
 
    if (!pem_key) {
-      MONGOC_WARNING ("Couldn't find certificate in '%d'", opt->ca_file);
+      MONGOC_WARNING ("Couldn't find certificate in '%s'", opt->ca_file);
       return false;
    }
 
@@ -350,7 +348,7 @@ mongoc_secure_channel_setup_ca (
                               NULL,
                               NULL)) {
       MONGOC_ERROR ("Failed to convert BASE64 public key. Error 0x%.8X",
-                    GetLastError ());
+                    (unsigned int) GetLastError ());
       return false;
    }
 
@@ -363,7 +361,7 @@ mongoc_secure_channel_setup_ca (
                               NULL,
                               NULL)) {
       MONGOC_ERROR ("Failed to convert BASE64 public key. Error 0x%.8X",
-                    GetLastError ());
+                    (unsigned int) GetLastError ());
       return false;
    }
 
@@ -413,7 +411,7 @@ mongoc_secure_channel_setup_crl (
       MONGOC_WARNING ("Can't determine opt->crl_file length");
       return false;
    }
-   str = (LPWSTR) bson_malloc0 (chars);
+   str = (LPWSTR) bson_malloc0 (chars * sizeof (*str));
    MultiByteToWideChar (CP_ACP, 0, opt->crl_file, -1, str, chars);
 
 
@@ -431,7 +429,7 @@ mongoc_secure_channel_setup_crl (
       NULL, /* phCertStore, OUT, HCERTSTORE.., unused, for now */
       NULL, /* phMsg, OUT, HCRYPTMSG, only for PKC7, unused */
       (const void **) &cert /* ppvContext, OUT, the Certificate Context */
-   );
+      );
    bson_free (str);
 
    if (!cert) {
@@ -611,10 +609,10 @@ mongoc_secure_channel_handshake_step_1 (mongoc_stream_tls_t *tls,
       &outbuf_desc,                       /* pOutput OUT param */
       &secure_channel->ret_flags,         /* pfContextAttr OUT param */
       &secure_channel->ctxt->time_stamp   /* ptsExpiry OUT param */
-   );
+      );
 
    if (sspi_status != SEC_I_CONTINUE_NEEDED) {
-      MONGOC_ERROR ("initial InitializeSecurityContext failed: %d",
+      MONGOC_ERROR ("initial InitializeSecurityContext failed: %ld",
                     sspi_status);
       return false;
    }
@@ -706,9 +704,9 @@ mongoc_secure_channel_handshake_step_2 (mongoc_stream_tls_t *tls,
          secure_channel->encdata_offset += nread;
       }
 
-      TRACE ("encrypted data buffer: offset %zu length %zu",
-             secure_channel->encdata_offset,
-             secure_channel->encdata_length);
+      TRACE ("encrypted data buffer: offset %d length %d",
+             (int) secure_channel->encdata_offset,
+             (int) secure_channel->encdata_length);
 
       /* setup input buffers */
       _mongoc_secure_channel_init_sec_buffer (
@@ -821,10 +819,8 @@ mongoc_secure_channel_handshake_step_2 (mongoc_stream_tls_t *tls,
                           "has expired");
             break;
          case CRYPT_E_NO_REVOCATION_CHECK:
-            /* This seems to be raised also when hostname doesn't match the
-             * certificate */
-            MONGOC_ERROR ("SSL Certification verification failed: failed "
-                          "revocation/hostname check");
+            MONGOC_ERROR ("SSL Certification verification failed: certificate "
+                          "does not include revocation check.");
             break;
 
          case SEC_E_INSUFFICIENT_MEMORY:
@@ -856,8 +852,8 @@ mongoc_secure_channel_handshake_step_2 (mongoc_stream_tls_t *tls,
                            NULL);
             MONGOC_ERROR ("Failed to initialize security context, error code: "
                           "0x%04X%04X: %s",
-                          (sspi_status >> 16) & 0xffff,
-                          sspi_status & 0xffff,
+                          (unsigned int) (sspi_status >> 16) & 0xffff,
+                          (unsigned int) sspi_status & 0xffff,
                           msg);
             LocalFree (msg);
          }
